@@ -20,8 +20,8 @@ class PPSgen(GridElement):
 
         self.current_bus_voltage = 1.0
         self.in_service = True
-        self.p_mw = 0
-        self.q_mvar = 0
+        self.p_mw = getattr(grid, self.pp_key()).p_mw.iloc[index]
+        self.q_mvar = getattr(grid, self.pp_key()).q_mvar.iloc[index]
 
         self._constraints.append(ConstraintSgenVoltageChange(self, value))
 
