@@ -35,7 +35,7 @@ class ConstraintedGrid(PandapowerGrid):
     def run_powerflow(self, time):
 
         # Run once to check current state
-        super().run_powerflow(0)
+        super().run_powerflow(time)
 
         state_changed = False
         # Now constraints can change the input state if necessary
@@ -44,7 +44,7 @@ class ConstraintedGrid(PandapowerGrid):
                 state_changed = element.step(time) or state_changed
 
         if state_changed:
-            super().run_powerflow(0)
+            super().run_powerflow(time)
 
     def _load_constraints(self):
         for constr in self._constraints_to_load:
