@@ -27,8 +27,8 @@ class PandapowerGrid:
 
         self._output_map = {
             "bus": ["p_mw", "q_mvar", "vm_pu", "va_degree"],
-            "load": ["p_mw", "q_mvar"],
-            "sgen": ["p_mw", "q_mvar"],
+            "load": ["p_mw", "q_mvar", "in_service"],
+            "sgen": ["p_mw", "q_mvar", "in_service"],
             "trafo": ["va_lv_degree", "loading_percent"],
             "line": [
                 "i_ka",
@@ -37,11 +37,12 @@ class PandapowerGrid:
                 "p_to_mw",
                 "q_to_mvar",
                 "loading_percent",
+                "in_service",
             ],
             "ext_grid": ["p_mw", "q_mvar"],
             # "slack": ["p_mw", "q_mvar"],
             "switch": ["et", "type", "closed"],
-            "storage": ["p_mw", "q_mvar"],
+            "storage": ["p_mw", "q_mvar", "in_service"],
         }
 
     def setup(self, gridfile, grid_idx, grid_params=None):
@@ -100,14 +101,21 @@ class PandapowerGrid:
 
             element = self.grid[key].iloc[attrs["idx"]]
             for output in self._output_map[etype]:
-                if self.lf_converged:
-                    data[output] = element[output]
-                else:
-                    if etype == "switch":
-                        # Switches don't have numerical outputs
+                if (
+                    self.lf_converged
+                    or etype == "switch"
+                    or output == "in_service"
+                ):
+                    # Switches don't have numerical outputs
+                    # in_service is boolean
+                    try:
                         data[output] = element[output]
-                    else:
-                        data[output] = 0  # Return nan?
+                    except KeyError:
+                        data[output] = self.grid[etype].iloc[attrs["idx"]][
+                            output
+                        ]
+                else:
+                    data[output] = 0  # Return nan?
 
             self.cache[eid] = data
 
